import React from 'react';
import PropTypes from 'prop-types';
import { Form, Button, Select } from 'antd';
import XItem2 from './Item';
import { isFunction, isEmpty } from './utils';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 8 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
};

class Form2 extends React.PureComponent {
  state = {}

  handleSubmit = e => {
    e.preventDefault();
    const { form, onError, onSubmit } = this.props

    form.validateFieldsAndScroll((err, values) => {
      if (err) {
        if (isFunction(onError)) {
          onError(err)
        } else {
          window.console.error(err)
        }
      } else {
        if (isFunction(onSubmit)) {
          onSubmit(values)
        }
      }
    });
  }

  handleCancel = e => {
    e.preventDefault();

    if (isFunction(this.props.onCancel)) {
      this.props.onCancel()
    }
  }

  renderDefaultAction = (submitBtn, cancelBtn) => {
    let FieldSubmit = null
    let FieldCancel = null
    if (submitBtn !== false) {
      FieldSubmit = <Button htmlType="submit" type="primary">提交</Button>
    }
    if (cancelBtn !== false) {
      FieldCancel = <Button htmlType="button" onClick={this.handleCancel} style={{ marginLeft: '48px' }}>取消</Button>
    }

    return FieldSubmit || FieldCancel ? <XItem2 action render={() => (<>{FieldSubmit}{FieldCancel}</>)} /> : null
  }

  render () {
    const {fields, form, children, submitBtn, cancelBtn, ...formProps} = this.props;

    console.log('---------render parent------------')

    return (
      <Form {...formItemLayout} {...formProps} onSubmit={this.handleSubmit}>
        {children}
        {/* {FeildItems} */}
        {this.renderDefaultAction(submitBtn, cancelBtn)}
      </Form>
    );
  }
}

Form2.propTypes = {
  fields: PropTypes.array.isRequired,
  form: PropTypes.object.isRequired,
  dataset: PropTypes.object,
}

export default Form2;
