# XForm2
基于原来的 XForm 思想, 重新封装了一个表单。主要解决以下几个问题

* 支持任意的表单组件， 不再受限
* 支持组件的动态显示

## 引用
```jsx
import createForm from 'path/to/xform2';
```

## 使用
### 创建 Form

```jsx
// https://ant.design/components/form-cn/#Form.create(options)
const options = {}

// options 也可以不传
const Form = createForm(options)

// 这样就可以使用 Form 了
class MyComponent extends React.Component {
  render() {
    return (
      <Form onSubmit={xxx}></Form>
    );
  }
}

```

生成的 Form 有如下 Props 设置

| prop | 说明 | 类型 |
|---|---|---|
| onSubmit | 表单提交 | function(allFieldValues) {} |
| onCancel | 表单取消 | function() {} |
| submitBtn | 是否显示提交按钮 | 布尔值: 默认 true |
| cancelBtn | 是否显示取消按钮 | 布尔值: 默认 true |
| ... | 其他 [Antd Form](https://ant.design/components/form-cn/#Form) 支持的属性 |  |

### 添加表单字段

```jsx
import React from 'react';
import { Input, Select } from 'antd';

const fields = [
        {
          label: '标题',
          name: 'title',
          placeholder: '填写标题',
          node: Input,
          value: data.title,
        },
        {
          label: '发布位置',
          name: 'showPosition',
          node: Select,
          options: [
            { 
              label: '首页',
              value: 'index',
            },
            {
              label: '积分商城',
              value: 'mall',
            }
          ],
          value: data.showPosition,
          hidden: values => values.title === 'foobar',
        },
      ];


// some codes
// <Form onSubmit={xxx} fields={fields}></Form>

```

表单字段是通过 `json` 配置实现的。支持的属性有

| 属性 | 说明 | 类型 |
|---|---|---|
| label | 字段文字标题 | string 或者 function(allFieldValues, props), 非必填 |
| name | 字段 name | string, 非必填 |
| node | 字段节点, 注意不是 `React.Element`。也就是不能是 `<Input />`, 而是 `Input` | react elementType 或者 可以生成 `React.Element` 的函数, 非必填 |
| children | 字段如果复杂, 需要子元素。 子元素不能是节点, 必须是 `React.Element` | react element 或者 函数, 非必填 |
| options | 如果 node 是 `antd.Select`, 这里提供了一个快捷方式自定义 `option` 列表 | array, 元素格式 `{ label: xxx, value: xxx }`, 非必填 |
| render | 自定义的字段渲染逻辑 | function(props) {}, 非必填 |
| action | 是否为功能类组件, 比如按钮 | boolean: 默认 false |
| value | 字段默认值 | any: 非必填 |
| placeholder | 字段 placeholder | string 或者 function(allFieldValues, props), 非必填 |
| rules | 字段校验规则, 与 [antd.Form](https://ant.design/components/form-cn/#%E6%A0%A1%E9%AA%8C%E8%A7%84%E5%88%99) 的约定一致 | 类型 array: 非必填 |
| props | 其余需要传入字段组件的属性或者事件 | object: 非必填 |
| hidden | 如果有 `name`, 此值又是 `true`. 那么该字段则为隐藏字段放入 form 中。另外, 则为设置组件的显示, 隐藏 | boolean 或者 function(allFieldValues, props) : 非必填, 默认 false |

## 注意事项
* 字段组件支持自定义封装, 但是封装组件必须满足2个条件。1、值传递通过 `value` 属性, 2、提供 `onChange` 事件
* 字段组件必须支持 `ref` 传递. 因此函数式组件, 请使用 `React.forwardRef` 包裹起来
