import React, { useState, useEffect } from 'react';
import { Input, Menu, Dropdown, Button, Icon, message, Table, Divider, Tag, Select, Form, Alert } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import channels from '../../channel/channelList.less';
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import { createForm, FieldTypes } from '../../../components/XForm';
import Wangedit from '../../../components/Wangedit/Wangedit'
import router from 'umi/router';
import apis from '../../../services/apis';
import request from '../../../utils/request'

const { TextArea } = Input;
const { Option } = Select;

let activityVisible = true

const setExtraData = (data) => {
    console.log(data, 'data');
    activityVisible = data.imgType === 'index';
  }

const handleFormValueChange = (props, changedValues, allValues) => {
    setExtraData(allValues)
}

const XForm = createForm({ onValuesChange: handleFormValueChange })

const header = props => {
  
  const imgId = props.location.query.imgId
  const [ data, setData ] = useState({'imgUrl':'https://estateagents.oss-cn-shanghai.aliyuncs.com/miniapp/upload/images/1574145199853-97feda7895c65be33aa234a7b81b37f.jpg','imgType':'index','imgDesc':'小程序首页分享配图','imgDocument': '小程序名字 精准获客平台'})
  if(imgId){
    useEffect(() => {
      getData(imgId);
    },[])

  // 查询列表
  const getData = (imgId) => {
    request({ ...apis.carsuseFigure.getCustomImg, urlData: { id: imgId} }).then((data) => {
        console.log(data)
        if (data.imgType === 'index'){
            activityVisible = true;
        }else{
            activityVisible = false;
        }
        setData(data)
    })
  }
  }

  const fields = [
    {
      label: '图片',
      name: 'imgUrl',
      type: FieldTypes.ImageUploader,
      value: data.imgUrl,
      help: '建议图片尺寸：750*600px，比例5:4,格式：jpg，用于：首页分享',
      rules: [
        {required: true, message: '请选择图片'},
      ]
    },
    {
      label: '类型',
      name: 'imgType',
      type: FieldTypes.Select,
      value: 'index',
      dict: [{
          label: '首页分享',
          value: 'index',
        },
      ],
      rules: [
        { required: true, message: '请选择类型' },
      ],
    },
    {
      label: '分享文案',
      name: 'imgDocument',
      type: FieldTypes.Text,
      value: data.imgDocument,
      rules: [
        { required: true, message: '请输入分享文案' },
      ],
    },
  ]

  const handleSubmit = values => {
    
    if (imgId) {
      values.imgId = imgId
      request({ ...apis.carsuseFigure.updateCustomImg, data: values,}).then((data) => {
        cancelPage()
      }).catch((err) => {
        message.info(err.msg || err.message)
      })
      }else{
      request({ ...apis.carsuseFigure.addCustomImg, data: values,}).then((data) => {
        cancelPage()
      }).catch((err) => {
        message.info(err.msg || err.message)
      })
      }
  }

  const cancelPage = () => {
    router.push({
        pathname: '/carouselFigure/customImg/list',
    });
  }

  return (
    <XForm onSubmit={handleSubmit} onCancel={cancelPage} fields={fields}></XForm>
  )
}

const WrappedNormalLoginForm = Form.create({ name: 'header' })(header);
export default WrappedNormalLoginForm
